# Summary: How AI, tariffs, and the energy transition are reshaping infrastructure investing

**Channel:** Goldman Sachs Exchanges

**Summary Generated:** 2025-06-03 02:18:30

**Language:** English

---

## Summary Content

This podcast episode of Goldman Sachs Exchanges, titled "How AI, tariffs, and the energy transition are reshaping infrastructure investing," features a discussion between host Alison Nathan and Tavis Kanell, Global Head of Infrastructure within Goldman Sachs Alternatives. They explore the evolving landscape of infrastructure investing in response to major global megatrends.

---

### 1. Main Topics Outline (in sequence)

1.  **Introduction:** Setting the stage – megatrends reshaping infrastructure investing.
2.  **The Role of Infrastructure in Portfolios:** Why investors are increasing allocation to infrastructure.
3.  **Defining Modern Infrastructure:** Evolution from traditional assets to new segments.
4.  **Deep Dive: Digital Infrastructure:** Focus on data centers, AI demand, and associated challenges/opportunities.
5.  **Generating Infrastructure Investment Returns:** Mechanisms for value creation.
6.  **Deep Dive: Energy Transition:** Impact of the Inflation Reduction Act (IRA) and policy outlook.
7.  **Promising Opportunities in Energy Transition:** Specific areas of investment focus.
8.  **Geographical Trends:** Comparison of investment opportunities in the US, Europe, and emerging markets.
9.  **Deep Dive: Circular Economy:** Focus on sustainability-driven infrastructure.
10. **Navigating Geopolitical Uncertainty, Tariffs, and Market Volatility:** Challenges and opportunities in the current environment.
11. **Conclusion:** Overall outlook for infrastructure investing.

---

### 2. Comprehensive and Detailed Summary on Each Section Sequentially

**1. Introduction:**
Alison Nathan introduces the episode, highlighting that artificial intelligence (AI), geopolitical tensions (including tariffs), and the energy transition are profoundly reshaping the global economy and, consequently, the landscape of infrastructure investing. She introduces Tavis Kanell, Global Head of Infrastructure at Goldman Sachs Alternatives, who will provide insights into these megatrends and their impact on the sector.

**2. The Role of Infrastructure in Portfolios:**
Tavis Kanell explains why infrastructure has become a crucial asset class for institutional investors, who have progressively increased their allocations to 6-7% of total assets over the past decade. He cites three main reasons:
    *   **Diversification:** Infrastructure has a low correlation with public equities, fixed income, and other private asset classes, offering portfolio diversification.
    *   **Resilience:** It demonstrates strong resilience during economic uncertainty and high inflation. Since early 2022, infrastructure has returned 9% compounded, significantly outperforming buyout private equity (5%) and real estate (-2%) during a period of high inflation, war, and geopolitical tensions.
    *   **Attractive Absolute Returns:** Many strategies within infrastructure target mid-teens-plus returns, which are highly attractive when compounded over 5-10 years.

**3. Defining Modern Infrastructure:**
Tavis clarifies that "infrastructure today is not your mom or dad's infrastructure anymore." The asset class has significantly expanded over the last 10-15 years, reflecting evolving societal needs.
    *   Fifteen years ago, transport comprised about two-thirds of the infrastructure market; today, it's less than 20% of investment volumes.
    *   The two biggest segments now are **energy/energy transition** and **digital infrastructure**.
    *   Goldman Sachs' approach divides infrastructure into four key segments:
        1.  **Energy and Energy Transition:** Including traditional power and renewable energy.
        2.  **Digital Infrastructure:** Encompassing data centers, fiber optic networks, and cell towers.
        3.  **Transport and Logistics:** Broadening beyond traditional transport to include the entire supply chain ecosystem.
        4.  **Circular Economy:** Focusing on water, wastewater, and sustainable business models.

**4. Deep Dive: Digital Infrastructure:**
The discussion delves into data centers, particularly given the skyrocketing demand from AI.
    *   There's still massive ongoing investment in cloud build-out.
    *   AI training models have different requirements than cloud inference (e.g., greater proximity to population centers, immense scale, and significantly higher power intensity due to GPU compute output).
    *   **Investor Concerns:** While development is rampant, the capital markets for selling stabilized data center assets are not fully developed. Investors are also contemplating the residual value and longevity of AI-specific data centers, especially those in remote, power-proximate locations.
    *   **Opportunities in Credit & Power:** There's significant credit financing activity for the AI build-out. Crucially, the enormous power consumption of data centers is driving a secular growth in power demand (3-4% annually after 20 years of flatness), creating massive investment opportunities in the power generation and transmission sectors.

**5. Generating Infrastructure Investment Returns:**
Tavis explains how returns are made in infrastructure:
    *   **Value-Add/Higher Returns:** Typically pursued through "private equity in infrastructure" via **closed-ended funds**. Managers acquire companies at attractive valuations, drive value creation during a 5-7 year ownership period, and then sell, generating capital gains in addition to ongoing income.
    *   **Evergreen/Perpetual Vehicles:** These are long-term vehicles, some for institutional investors and more recently for private wealth. They target slightly lower but still compelling returns through compounding capital appreciation over time.

**6. Deep Dive: Energy Transition:**
The conversation addresses the impact of the Inflation Reduction Act (IRA) and the outlook for clean energy.
    *   **Cost Competitiveness:** Tavis asserts that most clean energy technologies, like solar paired with battery storage, are already cost-competitive without subsidies, based on **levelized cost of energy (LCOE)**. The IRA primarily enhanced existing tax credits.
    *   **IRA Outlook:** While a full repeal of the IRA is deemed unlikely, some areas (e.g., offshore wind, EV charging incentives, Department of Energy loans) are expected to be tweaked or partially repealed, as telegraphed by the administration.
    *   **Need for Clarity:** For long-term investments (typically 30+ year asset lives), investor confidence hinges on policy clarity and certainty, which is currently lacking.

**7. Promising Opportunities in Energy Transition:**
Despite policy noise, Tavis identifies several promising areas:
    *   **Utility-Scale Solar Generation:** Large-scale solar projects.
    *   **Distributed Generation:** Smaller-scale projects where generation is directly linked to usage (e.g., on-site solar for businesses). This segment is particularly attractive because it bypasses major grid **interconnection** constraints, allowing faster project delivery and offering a cost advantage to end consumers.
    *   **Energy Efficiency:** Significant opportunities exist in helping corporates upgrade outdated power usage systems with modern, more efficient technologies.

**8. Geographical Trends:**
Tavis provides a geographical comparison of infrastructure markets:
    *   **US vs. Europe:** Unusually, the infrastructure markets in the US and Europe are almost exactly the same size (unlike other asset classes where the US is typically 2-5 times larger), making Europe a very relevant investment market.
    *   **Europe's Shift:** Sentiment has recently tilted towards Europe, driven by Germany's €500 billion infrastructure investment plan, renewed focus on **permitting reform** (making it easier to build), and a recognition that infrastructure investment can accelerate growth. Governments and corporates in Europe need private capital to fund these initiatives.
    *   **Emerging Markets:** While Goldman Sachs' strategy focuses on developed markets, emerging markets like India and the Middle East (increasingly a destination for capital) have massive investment needs, though they come with higher political and foreign currency risks.

**9. Deep Dive: Circular Economy:**
Europe, especially Northern Europe, is at the forefront of the circular economy, driven by a strong focus on sustainability.
    *   This segment deals with circular business models, waste management, and water/wastewater systems.
    *   Much of the existing infrastructure in this space (both in Europe and the US) is 30-50 years old and requires significant investment.
    *   **Modular Buildings:** An example highlighted is modular buildings for healthcare or education, which offer long-term contracts (often with governments), possess 30-year lives, exhibit energy efficiency, and provide flexible solutions.

**10. Navigating Geopolitical Uncertainty, Tariffs, and Market Volatility:**
Tavis addresses the challenges and opportunities presented by the current volatile environment:
    *   **Tariffs:** The biggest impact is on supply chain risks for significant capital expenditures. Prudent managers have mitigated short-term risks by pre-ordering equipment. The longer-term question is whether supply chains need reorientation, an area where "muscle memory" from COVID-related disruptions is helpful.
    *   **Domestic Regulation:** Directly regulated infrastructure assets (those touching consumers/voters) face unpredictable regulatory outcomes in politically sensitive, high-cost-of-living environments, potentially impacting pricing and investor returns.
    *   **Opportunities from Dislocation:** Broadly, volatile environments create opportunities because assets are "not priced to perfection." This leads to:
        *   **Public-to-Privates:** Delisting public companies (where long-term infrastructure businesses may be undervalued by public markets) becomes more attractive.
        *   **Corporate Carve-outs/Spin-outs:** Corporates and governments reassess asset ownership, leading to more opportunities for private capital to invest in spun-out infrastructure assets.

**11. Conclusion:**
Tavis concludes that it's a "pretty good time to be investing in infrastructure." This is due to both cyclical market dynamics and, more importantly, the perfect alignment of infrastructure with major global megatrends: decarbonization, digitalization, and deglobalization/geopolitical shifts. The asset class provides direct access to these powerful thematics.

---

### 3. Key Insights and Takeaways

*   **Infrastructure's Evolving Definition:** It's no longer just roads and bridges but heavily concentrated in digital and energy transition assets, reflecting evolving societal needs.
*   **Portfolio Resilience:** Infrastructure offers strong diversification, resilience against inflation and volatility, and attractive absolute returns, outperforming many other asset classes in recent challenging periods.
*   **AI and Energy Transition as Core Drivers:** These two megatrends are driving immense, long-term investment needs in data centers, power generation, and related infrastructure.
*   **Power Demand Resurgence:** After decades of flatness, power demand is growing significantly (3-4% annually), largely due to data centers, creating vast investment opportunities in the power sector.
*   **Policy Certainty is Paramount:** For long-lived infrastructure assets, clarity and stability in government policy (e.g., regarding the IRA, tariffs) are crucial for unlocking significant private capital investment.
*   **Opportunities in Volatility:** While geopolitical and regulatory uncertainties pose challenges, the resulting market dislocation often creates attractive entry points for investors, particularly through public-to-private transactions and corporate spin-offs.
*   **Europe's Resurgence:** Europe is a major and increasingly attractive market for infrastructure, driven by substantial investment plans and permitting reforms.
*   **Circular Economy as a Growth Area:** Sustainability-focused infrastructure, particularly in Europe, presents compelling investment opportunities.
*   **Supply Chain Adaptation:** The industry is learning to manage tariff-related supply chain risks, applying lessons from COVID-era disruptions.

---

### 4. Important Quotes or Statements

*   "It's not your mom or dad's infrastructure anymore."
*   "Most large institutional investors have around 6, 7 percent of their total assets invested into infrastructure."
*   "Since the beginning of 2022, infra has returned 9% compounded returns across the whole asset class. And that compares with like buyout private equity at 5%, real estate at like minus 2%."
*   "The two biggest segments in infrastructure today are energy, energy transition, and digital infrastructure."
*   "The power consumption needed for these data centers is enormous... we're in a secular growth where power demand is growing 3%, 4% a year."
*   "Most clean energy technologies are actually cost competitive without subsidies."
*   "What's important is clarity. These are investments that are typically... 30 year plus lives for an underlying investment... you need the certainty in order to make these long term, very significant capital investments."
*   "The single biggest constraint, including on data centers and on energy transition generally, is the grid. And it's what's called interconnection."
*   "In infrastructure, the two [US & European] markets are actually almost exactly the same size, which is quite unusual."
*   "These type of environments tend to be really interesting environments for us to invest because what we'd say there's a lot of dislocation and there's a lot of noise. And that usually means that things are not priced to perfection."
*   "The most exciting thing about infrastructure is that it's a way to really invest behind these big megatrends."

---

### 5. Key Terminology/Jargon Explanation

*   **Infrastructure Investing:** Traditionally referred to public works like roads, bridges, utilities. Modern definition expands to include essential digital assets (data centers, fiber) and energy transition assets (renewables, grid modernization).
*   **Diversifier:** An asset class that has a low correlation with other asset classes in a portfolio, meaning its returns tend to move independently, helping to reduce overall portfolio risk.
*   **Correlation:** A statistical measure that indicates the extent to which two or more variables move in relation to each other. Low correlation means they don't move in sync.
*   **Compounded Returns:** Returns that include the gains from previous periods reinvested, leading to exponential growth over time.
*   **Absolute Returns:** The total return of an investment, expressed as a percentage or currency amount, not compared to a benchmark.
*   **Risk-Return Spectrum:** A range of investment options, from low risk/low potential return to high risk/high potential return.
*   **Energy Transition:** The global shift from fossil fuel-based energy systems to renewable and low-carbon energy sources.
*   **Digital Infrastructure:** The physical components necessary for the digital economy, including data centers, fiber optic cables, and cell towers.
*   **Circular Economy:** An economic system aimed at eliminating waste and the continual use of resources. It involves designing out waste and pollution, keeping products and materials in use, and regenerating natural systems.
*   **Hyperscale (Cloud Providers):** Refers to the massive, highly scalable data centers operated by major cloud service providers (e.g., Amazon Web Services, Microsoft Azure, Google Cloud).
*   **GPU (Graphics Processing Unit):** Specialized electronic circuits designed to rapidly manipulate and alter memory to accelerate the creation of images, crucial for AI computations.
*   **Moore's Law:** The observation that the number of transistors in an integrated circuit doubles approximately every two years, leading to exponential growth in computing power. (Applied here to GPU output).
*   **Closed-Ended Funds:** Investment funds that have a fixed number of shares or units, typically raised once from investors, and are not continuously open for subscriptions or redemptions. Common in private equity and private infrastructure.
*   **General Partners (GPs):** The managing partners of a private investment fund (like a private equity or infrastructure fund) who make investment decisions and are responsible for the fund's operations.
*   **Evergreen Vehicles / Perpetual Vehicles:** Investment funds that do not have a fixed maturity date and continuously accept new investments and make distributions, maintaining a perpetual life.
*   **Inflation Reduction Act (IRA):** A landmark US federal law enacted in 2022 that includes significant investments in clean energy and climate change mitigation through tax credits and incentives.
*   **Levelized Cost of Energy (LCOE):** A metric used to compare the total cost of building and operating an electricity-generating asset over its lifetime, divided by the total energy output over that lifetime. It allows for comparison of different generation technologies.
*   **Offshore Wind, EV Charging, DOE Loans:** Specific types of clean energy projects or government incentives mentioned as potentially subject to changes under a new administration.
*   **Utility Scale vs. Distributed Generation:**
    *   **Utility Scale:** Large-scale energy projects (e.g., solar farms, wind farms) that feed power directly into the main electricity grid.
    *   **Distributed Generation:** Smaller-scale energy generation (e.g., rooftop solar, community solar) located at or near the point of consumption, often bypassing large transmission infrastructure.
*   **Interconnection (Grid):** The process of connecting a new power plant or renewable energy project to the existing electrical grid. It's often a major bottleneck.
*   **Permitting Reform:** Changes to regulatory processes to streamline and accelerate the approval of construction and infrastructure projects.
*   **Developed Markets vs. Emerging Markets:**
    *   **Developed Markets:** Countries with mature economies, high per capita income, and advanced industrialization (e.g., US, Europe, Japan).
    *   **Emerging Markets:** Countries that are in the process of rapid growth and industrialization, typically with lower per capita income but high growth potential (e.g., India, parts of the Middle East).
*   **Public-to-Private (Deals):** When a private equity or infrastructure fund acquires a publicly traded company and takes it private, delisting its shares from the stock exchange.
*   **Corporate Carve-outs / Spin-outs:** When a larger corporation sells off or spins off a specific business unit or asset, often to focus on its core operations. Infrastructure funds can then acquire and invest in these spun-out assets.
*   **Megatrends (Decarbonization, Digitalization, Deglobalization):** Large, transformative global forces that are expected to have a sustained, long-term impact on societies, economies, and markets.
    *   **Decarbonization:** The process of reducing carbon emissions, especially from energy production.
    *   **Digitalization:** The increasing integration of digital technologies into all aspects of life and business.
    *   **Deglobalization:** A trend towards less economic interdependence and integration between countries, often driven by geopolitical tensions and protectionist policies.

---

### 6. Overall Themes, and the Logic of the Opinions Expressed in the Podcast

**Overall Themes:**

1.  **Transformative Evolution of Infrastructure:** The central theme is that infrastructure is no longer a static, traditional asset class but a dynamic and rapidly evolving sector driven by fundamental societal shifts.
2.  **Resilience and Attractive Returns in Volatility:** Infrastructure is presented as a safe haven and a high-performing asset class during periods of economic and geopolitical uncertainty.
3.  **Megatrends as Investment Catalysts:** The podcast strongly argues that AI, the energy transition, and geopolitical shifts are not just challenges but powerful, long-term tailwinds creating massive investment opportunities in infrastructure.
4.  **The Interplay of Policy and Private Capital:** Government policy (e.g., IRA, tariffs, regulation) is crucial for shaping the investment landscape, and private capital is essential for meeting the immense funding needs.
5.  **Global Opportunities with Regional Nuances:** While opportunities are global, specific market dynamics and regulatory environments dictate regional attractiveness.

**Logic of the Opinions Expressed:**

*   **Logic for Infrastructure's Resilience:** Tavis argues that infrastructure's core characteristics—providing essential services, often with long-term contracts and inflation-linked revenues—make it inherently resilient. During times of inflation or economic stress, essential services are less discretionary, and their revenues can often adjust upwards. The data (9% compounded returns since 2022) supports this claim, comparing it favorably to more cyclical private equity and real estate. This makes infrastructure a compelling diversifier.
*   **Logic for AI and Energy Transition as Key Drivers:** The argument is that these are not fleeting trends but fundamental shifts requiring massive physical investment.
    *   **AI:** The exponential growth in AI directly translates into immense power consumption and demand for data centers, which are physical infrastructure assets. This creates a clear, measurable need for capital.
    *   **Energy Transition:** The global push towards decarbonization, whether policy-driven or cost-driven (as he states clean energy is often competitive without subsidies), necessitates a complete overhaul of energy generation, transmission, and consumption infrastructure. This is a multi-decade investment cycle.
*   **Logic for Policy Clarity:** Infrastructure projects are typically long-lived (30+ years). Investors committing capital to such long-term assets need a predictable regulatory and policy environment to assess risks and returns accurately. Uncertainty deters investment because the long-term cash flows cannot be reliably forecast.
*   **Logic for Opportunities in Volatility:** Tavis applies a classic private equity logic: Public markets often undervalue long-term, stable assets during periods of short-term volatility or confusion. This creates an arbitrage opportunity for private capital, which can acquire these assets at attractive prices, deploy expertise, and benefit from their underlying long-term stability and growth. Corporate carve-outs also happen when companies reassess their core focus in turbulent times, offloading non-core infrastructure assets that private investors specialize in.
*   **Logic for Europe's Attractiveness:** The perception shift towards Europe is based on concrete developments: large government spending commitments (e.g., Germany's €500bn plan), policy reforms (permitting), and the recognition by European governments that private capital is indispensable for driving growth through infrastructure investment given strained public finances. Europe also has a strong inherent focus on sustainability, aligning with circular economy opportunities.

---

### 7. Critical Thinking and Analysis for this Podcast, Reasoning from First Principles

**1. A Pitch, Not Purely Objective Analysis:**
*   **First Principle:** *Consider the source and their incentives.* Tavis Kanell is the Global Head of Infrastructure at Goldman Sachs Alternatives. His role is to attract capital to infrastructure investments. Therefore, the podcast functions, to a significant extent, as an advocacy piece for the asset class. While the data and trends he presents are likely accurate from a Goldman Sachs perspective, the narrative naturally emphasizes the positives and frames challenges as opportunities.
*   **Analysis:** The podcast is highly optimistic about infrastructure. This is not necessarily a bad thing, but listeners should be aware of the inherent bias. For example, while 9% compounded returns since 2022 are impressive, such figures can be selective (e.g., what about returns before 2022? Are these gross or net of fees? What is the impact of leverage on these returns?). Similarly, the "mid-teens plus" return target is for "many strategies," implying not all.

**2. The "Resilience" Claim – Deeper Dive:**
*   **First Principle:** *What are the underlying mechanisms that create resilience?* Infrastructure often involves long-term contracts, essential services (demand tends to be inelastic), and frequently, inflation-linked revenues (e.g., tolls, utility rates that can adjust with inflation). These structural characteristics *should* confer resilience.
*   **Analysis:** The 9% return figure in a period of high inflation and rising rates is indeed strong evidence of resilience. However, infrastructure often involves significant debt financing. While interest rates have risen, the podcast doesn't explicitly discuss how increased financing costs might impact future returns, though the past performance suggests existing structures may have been robust. Future resilience will depend on the cost of capital.

**3. AI and Data Centers – Infrastructure or Tech Risk?**
*   **First Principle:** *What defines "infrastructure" and how does it differ from other asset classes, especially technology?* Traditionally, infrastructure assets are long-lived, physical, and relatively immune to rapid technological obsolescence (e.g., a bridge or a power plant).
*   **Analysis:** Tavis himself raises the "residual value" and "how long are they going to last?" questions for AI training data centers. This is a critical point. If the underlying technology (GPUs, AI models) evolves extremely rapidly, making current data center configurations or locations obsolete in 5-10 years, then these assets take on more characteristics of technology investments than traditional infrastructure. While the *demand for power* is infrastructural, the *data center itself* might carry higher tech-related obsolescence risk than, say, a water treatment plant. Investors need to differentiate between the power generation/transmission needed for AI (true infrastructure) and the specialized data center facilities (potentially more tech-exposed).

**4. Policy Uncertainty – The Double-Edged Sword:**
*   **First Principle:** *How do long-term investments react to short-term political volatility?* Long-lived assets require predictable regulatory frameworks.
*   **Analysis:** Tavis correctly identifies policy clarity as crucial. His optimism about a full IRA repeal being unlikely, though admitted to be a political prediction, is plausible given the economic benefits and the difficulty of outright legislative reversal. However, the *tweaks* he mentions (offshore wind, EV charging) are significant. The lack of certainty on these specific areas still creates a chilling effect on investment. While "dislocation" creates opportunities, it also creates risk – adverse regulatory outcomes (as seen in Europe) can severely impact returns in regulated assets, especially those touching consumers and voters in a "febrile economic environment." This highlights the political risk inherent in some infrastructure segments.

**5. Cost Competitiveness of Clean Energy – Nuance Needed:**
*   **First Principle:** *What are the true all-in costs and how do they compare?* "Cost competitive" is a key economic driver beyond subsidies.
*   **Analysis:** The claim that "most clean energy technologies are actually cost competitive without subsidies" (specifically solar+battery) is powerful if true. It suggests the energy transition is fundamentally an economic imperative, not just a policy-driven one. However, "cost competitive" against what? Often, it's against natural gas. This doesn't necessarily mean it's competitive against *all* forms of existing energy, or that it solves all grid stability issues without further investment in storage or grid modernization. The statement is strong but needs context for specific applications and geographical regions.

**6. Global Markets and Risk Differentiation:**
*   **First Principle:** *Investment opportunities are not uniform; risk profiles vary significantly by geography.*
*   **Analysis:** Tavis acknowledges the higher political and currency risks in emerging markets. This is a crucial distinction. While needs are vast in India or the Middle East, Goldman Sachs' preference for developed markets indicates a deliberate risk-adjusted approach. The "tilt towards Europe" highlights how regional political and economic stability (or perceived improvement) can quickly shift investment sentiment, even if the underlying asset needs are consistent. The discussion on permitting reform in Europe directly addresses a long-standing barrier to infrastructure development, demonstrating a pragmatic response to investment needs.

In conclusion, the podcast provides a compelling and well-articulated case for infrastructure investing, positioning it as a resilient and growth-aligned asset class amidst global megatrends. While inherently promotional, it offers valuable insights into the modern definition of infrastructure, the drivers of its growth, and the strategic considerations for investors, particularly regarding technology integration, policy uncertainty, and geographical dynamics. The critical points revolve around the specific risks within new infrastructure segments (like AI data centers) and the ongoing need for policy clarity despite the overall positive outlook.